@@ -94,7 +94,7 @@ class R3sponse(object):
 					return params, response
 			else: 
 				params[param] = param_value
-		return params, response
+		return params, self.success_response(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 	# check parameters.
 	def check_parameter(self, parameter=None, name="parameter", empty_value=None):
